@@ -20,6 +20,7 @@ INSERT INTO db_info (db_version) VALUES (2);
 
 ALTER TABLE disc ADD date_added date;
 ALTER TABLE disc ADD gain_adjustment int;
+ALTER TABLE disc MODIFY COLUMN artistid int NOT NULL;
 ALTER TABLE disc ADD KEY artistid(artistid);
 
 #
@@ -51,5 +52,7 @@ CREATE TABLE playlist_items (
 
 ALTER TABLE song ADD date_added date;
 ALTER TABLE song ADD gain_adjustment int;
+ALTER TABLE song MODIFY COLUMN artistid int NOT NULL;
 ALTER TABLE song ADD KEY artistid (artistid);
+ALTER TABLE song MODIFY COLUMN discid int NOT NULL;
 ALTER TABLE song ADD KEY discid (discid);
