@@ -36,6 +36,8 @@ typedef struct {
 
 gboolean StorePlaylistToDB(MYSQL *mysql,PlaylistInfo *list_info,IDList *idlist,
 			   gboolean overwrite);
+int PlaylistTypeFromStr(char *type_str);
+gboolean GetPlaylistInfoFromDB(MYSQL *mysql,int list_id,PlaylistInfo *pinfo);
 gboolean LoadPlaylistFromDB(MYSQL *mysql,int list_id,IDList *idlist);
 GtkWidget *PlaylistCList(MYSQL *mysql,GtkWidget **in_clist);
 void SelectPlaylist(MYSQL *mysql,gboolean allow_new,
